@@ -24,6 +24,8 @@ impl Pea2Pea for JoJoNode {
 
 #[async_trait::async_trait]
 impl Handshake for JoJoNode {
+    const TIMEOUT_MS: u64 = 10_000;
+
     async fn perform_handshake(&self, conn: Connection) -> io::Result<Connection> {
         // some handshakes are useful, others are menacing ゴゴゴゴ
         match !conn.side() {
@@ -109,10 +111,7 @@ impl Reading for JoJoNode {
             warn!(parent: self.node().span(), "{:?}!", reply);
         };
 
-        self.send_direct_message(source, reply)
-            .unwrap()
-            .await
-            .unwrap();
+        let _ = self.send_direct_message(source, reply).unwrap().await;
 
         Ok(())
     }
@@ -133,14 +132,12 @@ async fn main() {
 
     let config = Config {
         name: Some("Jotaro".into()),
-        max_handshake_time_ms: 10_000,
         ..Default::default()
     };
     let jotaro = JoJoNode(Node::new(Some(config)).await.unwrap());
 
     let config = Config {
         name: Some("Dio".into()),
-        max_handshake_time_ms: 10_000,
         ..Default::default()
     };
     let dio = JoJoNode(Node::new(Some(config)).await.unwrap());
@@ -156,11 +153,10 @@ async fn main() {
 
     sleep(Duration::from_secs(3)).await;
 
-    jotaro
+    let _ = jotaro
         .send_direct_message(dio_addr, BattleCry::Ora)
         .unwrap()
-        .await
-        .unwrap();
+        .await;
 
     sleep(Duration::from_secs(3)).await;
 }
