@@ -27,93 +27,44 @@ pub trait Writing: Pea2Pea
 where
     Self: Clone + Send + Sync + 'static,
 {
+    /// The depth of per-connection queues used to send outbound messages; the greater it is, the more outbound
+    /// messages the node can enqueue. Setting it to a large value is not recommended, as doing it might
+    /// obscure potential issues with your implementation (like slow serialization) or network.
+    ///
+    /// The default value is 64.
+    const MESSAGE_QUEUE_DEPTH: usize = 64;
+
     /// The type of the outbound messages; unless their serialization is expensive and the message
     /// is broadcasted (in which case it would get serialized multiple times), serialization should
     /// be done in the implementation of [`Self::Codec`].
     type Message: Send;
 
-    /// The user-supplied [`Encoder`] used to write the outbound messages to the target stream.
+    /// The user-supplied [`Encoder`] used to write outbound messages to the target stream.
     type Codec: Encoder<Self::Message, Error = io::Error> + Send;
 
     /// Prepares the node to send messages.
     async fn enable_writing(&self) {
-        let (conn_sender, mut conn_receiver) = mpsc::unbounded_channel::<ReturnableConnection>();
+        let (conn_sender, mut conn_receiver) = mpsc::unbounded_channel();
 
+        // the conn_senders are used to send messages from the Node to individual connections
         let conn_senders: WritingSenders = Default::default();
+        // procure a clone to create the WritingHandler with
+        let senders = conn_senders.clone();
 
         // use a channel to know when the writing task is ready
-        let (tx_writing, rx_writing) = oneshot::channel::<()>();
+        let (tx_writing, rx_writing) = oneshot::channel();
 
-        // the task spawning tasks reading messages from the given stream
+        // the task spawning tasks sending messages to all the streams
         let self_clone = self.clone();
-        let conn_senders_clone = conn_senders.clone();
         let writing_task = tokio::spawn(async move {
             trace!(parent: self_clone.node().span(), "spawned the Writing handler task");
             tx_writing.send(()).unwrap(); // safe; the channel was just opened
 
             // these objects are sent from `Node::adapt_stream`
-            while let Some((mut conn, conn_returner)) = conn_receiver.recv().await {
-                let addr = conn.addr();
-                let codec = self_clone.codec(addr);
-                let writer = conn.writer.take().unwrap();
-                let mut framed = FramedWrite::new(writer, codec);
-
-                let (outbound_message_sender, mut outbound_message_receiver) =
-                    mpsc::channel(self_clone.node().config().outbound_queue_depth);
-
-                // register the connection's message sender with the Writing protocol handler
-                conn_senders_clone
-                    .write()
-                    .insert(addr, outbound_message_sender);
-
-                // this will automatically drop the sender upon a disconnect
-                let auto_cleanup = SenderCleanup {
-                    addr,
-                    senders: Arc::clone(&conn_senders_clone),
-                };
-
-                // use a channel to know when the writer task is ready
-                let (tx_writer, rx_writer) = oneshot::channel::<()>();
-
-                // the task for writing outbound messages
-                let writer_clone = self_clone.clone();
-                let writer_task = tokio::spawn(async move {
-                    let node = writer_clone.node();
-                    trace!(parent: node.span(), "spawned a task for writing messages to {}", addr);
-                    tx_writer.send(()).unwrap(); // safe; the channel was just opened
-
-                    // move the cleanup into the task that gets aborted on disconnect
-                    let _auto_cleanup = auto_cleanup;
-
-                    while let Some(wrapped_msg) = outbound_message_receiver.recv().await {
-                        let msg = wrapped_msg.msg.downcast::<Self::Message>().unwrap();
-
-                        match writer_clone.write_to_stream(*msg, &mut framed).await {
-                            Ok(len) => {
-                                let _ = wrapped_msg.delivery_notification.send(true);
-                                node.known_peers().register_sent_message(addr, len);
-                                node.stats().register_sent_message(len);
-                                trace!(parent: node.span(), "sent {}B to {}", len, addr);
-                            }
-                            Err(e) => {
-                                let _ = wrapped_msg.delivery_notification.send(false);
-                                node.known_peers().register_failure(addr);
-                                error!(parent: node.span(), "couldn't send a message to {}: {}", addr, e);
-                                if node.config().fatal_io_errors.contains(&e.kind()) {
-                                    node.disconnect(addr).await;
-                                    break;
-                                }
-                            }
-                        }
-                    }
-                });
-                let _ = rx_writer.await;
-                conn.tasks.push(writer_task);
-
-                // return the Connection to the Node, resuming Node::adapt_stream
-                if conn_returner.send(Ok(conn)).is_err() {
-                    unreachable!("could't return a Connection to the Node");
-                }
+            while let Some(returnable_conn) = conn_receiver.recv().await {
+                self_clone
+                    .handle_new_connection(returnable_conn, &conn_senders)
+                    .await;
             }
         });
         let _ = rx_writing.await;
@@ -122,7 +73,7 @@ where
         // register the WritingHandler with the Node
         let hdl = Box::new(WritingHandler {
             handler: ProtocolHandler(conn_sender),
-            senders: conn_senders,
+            senders,
         });
         assert!(
             self.node().protocols.writing_handler.set(hdl).is_ok(),
@@ -131,20 +82,7 @@ where
     }
 
     /// Creates an [`Encoder`] used to write the outbound messages to the target stream.
-    fn codec(&self, _addr: SocketAddr) -> Self::Codec;
-
-    /// Writes the given message to the network stream and returns the number of written bytes.
-    async fn write_to_stream<W: AsyncWrite + Unpin + Send>(
-        &self,
-        message: Self::Message,
-        writer: &mut FramedWrite<W, Self::Codec>,
-    ) -> Result<usize, <Self::Codec as Encoder<Self::Message>>::Error> {
-        writer.feed(message).await?;
-        let len = writer.write_buffer().len();
-        writer.flush().await?;
-
-        Ok(len)
-    }
+    fn codec(&self, addr: SocketAddr) -> Self::Codec;
 
     /// Sends the provided message to the specified [`SocketAddr`]. Returns as soon as the message is queued to
     /// be sent, without waiting for the actual delivery; instead, the caller is provided with a [`oneshot::Receiver`]
@@ -160,7 +98,7 @@ where
         &self,
         addr: SocketAddr,
         message: Self::Message,
-    ) -> io::Result<oneshot::Receiver<bool>> {
+    ) -> io::Result<oneshot::Receiver<io::Result<()>>> {
         // access the protocol handler
         if let Some(handler) = self.node().protocols.writing_handler.get() {
             // find the message sender for the given address
@@ -209,14 +147,114 @@ where
     }
 }
 
+/// This trait is used to restrict access to methods that would otherwise be public in [`Writing`].
+#[async_trait]
+trait WritingInternal: Writing {
+    /// Writes the given message to the network stream and returns the number of written bytes.
+    async fn write_to_stream<W: AsyncWrite + Unpin + Send>(
+        &self,
+        message: Self::Message,
+        writer: &mut FramedWrite<W, Self::Codec>,
+    ) -> Result<usize, <Self::Codec as Encoder<Self::Message>>::Error>;
+
+    /// Applies the [`Writing`] protocol to a single connection.
+    async fn handle_new_connection(
+        &self,
+        (conn, conn_returner): ReturnableConnection,
+        conn_senders: &WritingSenders,
+    );
+}
+
+#[async_trait]
+impl<W: Writing> WritingInternal for W {
+    async fn write_to_stream<A: AsyncWrite + Unpin + Send>(
+        &self,
+        message: Self::Message,
+        writer: &mut FramedWrite<A, Self::Codec>,
+    ) -> Result<usize, <Self::Codec as Encoder<Self::Message>>::Error> {
+        writer.feed(message).await?;
+        let len = writer.write_buffer().len();
+        writer.flush().await?;
+
+        Ok(len)
+    }
+
+    async fn handle_new_connection(
+        &self,
+        (mut conn, conn_returner): ReturnableConnection,
+        conn_senders: &WritingSenders,
+    ) {
+        let addr = conn.addr();
+        let codec = self.codec(addr);
+        let writer = conn.writer.take().unwrap();
+        let mut framed = FramedWrite::new(writer, codec);
+
+        let (outbound_message_sender, mut outbound_message_receiver) =
+            mpsc::channel(Self::MESSAGE_QUEUE_DEPTH);
+
+        // register the connection's message sender with the Writing protocol handler
+        conn_senders.write().insert(addr, outbound_message_sender);
+
+        // this will automatically drop the sender upon a disconnect
+        let auto_cleanup = SenderCleanup {
+            addr,
+            senders: Arc::clone(conn_senders),
+        };
+
+        // use a channel to know when the writer task is ready
+        let (tx_writer, rx_writer) = oneshot::channel();
+
+        // the task for writing outbound messages
+        let self_clone = self.clone();
+        let writer_task = tokio::spawn(async move {
+            let node = self_clone.node();
+            trace!(parent: node.span(), "spawned a task for writing messages to {}", addr);
+            tx_writer.send(()).unwrap(); // safe; the channel was just opened
+
+            // move the cleanup into the task that gets aborted on disconnect
+            let _auto_cleanup = auto_cleanup;
+
+            while let Some(wrapped_msg) = outbound_message_receiver.recv().await {
+                let msg = wrapped_msg.msg.downcast().unwrap();
+
+                match self_clone.write_to_stream(*msg, &mut framed).await {
+                    Ok(len) => {
+                        let _ = wrapped_msg.delivery_notification.send(Ok(()));
+                        node.known_peers().register_sent_message(addr, len);
+                        node.stats().register_sent_message(len);
+                        trace!(parent: node.span(), "sent {}B to {}", len, addr);
+                    }
+                    Err(e) => {
+                        node.known_peers().register_failure(addr);
+                        error!(parent: node.span(), "couldn't send a message to {}: {}", addr, e);
+                        let is_fatal = node.config().fatal_io_errors.contains(&e.kind());
+                        let _ = wrapped_msg.delivery_notification.send(Err(e));
+                        if is_fatal {
+                            node.disconnect(addr).await;
+                            break;
+                        }
+                    }
+                }
+            }
+        });
+        let _ = rx_writer.await;
+        conn.tasks.push(writer_task);
+
+        // return the Connection to the Node, resuming Node::adapt_stream
+        if conn_returner.send(Ok(conn)).is_err() {
+            unreachable!("could't return a Connection to the Node");
+        }
+    }
+}
+
 /// Used to queue messages for delivery.
-pub(crate) struct WrappedMessage {
+struct WrappedMessage {
     msg: Box<dyn Any + Send>,
-    delivery_notification: oneshot::Sender<bool>,
+    delivery_notification: oneshot::Sender<io::Result<()>>,
 }
 
 impl WrappedMessage {
-    fn new(msg: Box<dyn Any + Send>) -> (Self, oneshot::Receiver<bool>) {
+    fn new(msg: Box<dyn Any + Send>) -> (Self, oneshot::Receiver<io::Result<()>>) {
         let (tx, rx) = oneshot::channel();
         let wrapped_msg = Self {
             msg,
@@ -230,7 +268,7 @@ impl WrappedMessage {
 /// The handler object dedicated to the [`Writing`] protocol.
 pub(crate) struct WritingHandler {
     handler: ProtocolHandler<Connection, io::Result<Connection>>,
-    pub(crate) senders: WritingSenders,
+    senders: WritingSenders,
 }
 
 impl Protocol<Connection, io::Result<Connection>> for WritingHandler {
@@ -239,7 +277,7 @@ impl Protocol<Connection, io::Result<Connection>> for WritingHandler {
     }
 }
 
-pub(crate) struct SenderCleanup {
+struct SenderCleanup {
     addr: SocketAddr,
     senders: WritingSenders,
 }
