@@ -7,6 +7,7 @@ use tokio::{
 use tracing::*;
 
 mod common;
+use crate::common::WritingExt;
 use pea2pea::{
     protocols::{Handshake, Reading, Writing},
     Config, Connection, ConnectionSide, Node, Pea2Pea,
@@ -137,8 +138,7 @@ async fn no_handshake_no_messaging() {
         .into();
 
     initiator
-        .send_direct_message(responder.node().listening_addr().unwrap(), message)
-        .unwrap()
+        .send_dm(responder.node().listening_addr().unwrap(), message)
         .await
         .unwrap();
 
@@ -160,6 +160,8 @@ impl Pea2Pea for Wrap {
 // is even made), but it is never provided by either of them
 #[async_trait::async_trait]
 impl Handshake for Wrap {
+    const TIMEOUT_MS: u64 = 100;
+
     async fn perform_handshake(&self, mut conn: Connection) -> io::Result<Connection> {
         let _ = self
             .borrow_stream(&mut conn)
@@ -172,12 +174,8 @@ impl Handshake for Wrap {
 
 #[tokio::test]
 async fn hung_handshake_fails() {
-    let config = Config {
-        max_handshake_time_ms: 10,
-        ..Default::default()
-    };
     let connector = Wrap(Node::new(None).await.unwrap());
-    let connectee = Wrap(Node::new(Some(config)).await.unwrap());
+    let connectee = Wrap(Node::new(None).await.unwrap());
 
     // note: the connector does NOT enable handshakes
     connectee.enable_handshake().await;
@@ -189,7 +187,7 @@ async fn hung_handshake_fails() {
         .await
         .is_ok());
 
-    // the TPC connection itself has been established, and with no reading, the connector doesn't know
+    // the TCP connection itself has been established, and with no reading, the connector doesn't know
     // that the connectee has already disconnected from it by now
     assert!(connector.node().num_connected() == 1);
     assert!(connector.node().num_connecting() == 0);
@@ -201,11 +199,9 @@ async fn hung_handshake_fails() {
 
 #[tokio::test(flavor = "multi_thread")]
 async fn timeout_when_spammed_with_connections() {
-    const NUM_ATTEMPTS: u16 = 200;
-    const TIMEOUT_MS: u64 = 100;
+    const NUM_ATTEMPTS: u16 = 100;
 
     let config = Config {
-        max_handshake_time_ms: TIMEOUT_MS,
         max_connections: NUM_ATTEMPTS,
         ..Default::default()
     };
